@@ -31,9 +31,13 @@ default_keys = (
     ("approve_requirement", int, []),
     ("assign_qualifications", bool, []),
     ("auto_recruit", bool, []),
-    ("aws_access_key_id", six.text_type, [], True),
-    ("aws_region", six.text_type, []),
-    ("aws_secret_access_key", six.text_type, [], True),
+    ("aws_access_key_id", six.text_type, ["AWS_ACCESS_KEY_ID"], True),
+    (
+        "aws_region",
+        six.text_type,
+        ["AWS_REGION", "AWS_DEFAULT_REGION", "aws_default_region"],
+    ),
+    ("aws_secret_access_key", six.text_type, ["AWS_SECRET_ACCESS_KEY"], True),
     ("base_payment", float, []),
     ("base_port", int, []),
     ("browser_exclude_rule", six.text_type, []),
